import 'package:consoledoctor_common/src/constants/brand_colors.dart';
import 'package:flutter/material.dart';
import 'package:consoledoctor_common/src/widgets/dialogs.dart' as dialogs;

extension ContextExtensions on BuildContext {

  /// Returns the appropriate brand color palette for the current theme
  BrandPalette get brandColors => BrandColors.of(this);

  /// Returns the navigator for the current context
  NavigatorState get navigator => Navigator.of(this);

  /// Returns a MediaQuery for the current context
  MediaQueryData get mediaQuery => MediaQuery.of(this);

  /// Returns thew size for the current context via MediaQuery
  Size get screenSize => mediaQuery.size;

  /// Returns the viewPadding for the current context via MediaQuery
  EdgeInsets get viewPadding => mediaQuery.viewPadding;

  /// Returns the systemGestureInsets for the current context via MediaQuery
  EdgeInsets get systemInsets => mediaQuery.systemGestureInsets;

  /// Returns textScaler for the current context via MediaQuery
  TextScaler get textScaler => mediaQuery.textScaler;

  /// Indicates whether the app is in dark mode
  bool get isDarkMode => Theme.of(this).brightness == Brightness.dark;

  /// Indicates whether the app is in light mode
  bool get isLightMode => Theme.of(this).brightness == Brightness.light;


  Future<void> showAlertMessage(String title, String body, { String buttonText = "OK"})
    => dialogs.showAlertMessage(this, title, body, buttonText: buttonText);
  Future<void> showAlert(String title, List<Widget> body, { String buttonText = "OK"})
    => dialogs.showAlert(this, title, body, buttonText: buttonText);
  Future<void> showNativeAlertMessage(String title, String body, { String buttonText = "OK"})
    => dialogs.showNativeAlertMessage(this, title, body, buttonText: buttonText);
  Future<void> showNativeAlert(String title, List<Widget> body, { String buttonText = "OK"})
    => dialogs.showNativeAlert(this, title, body, buttonText: buttonText);
  Future<bool?> showNativeYesNoAlert(String title, String message, {String yesButtonText = "YES", String noButtonText = "NO", bool allowModalClose = false})
    => dialogs.showNativeYesNoAlert(this, title, message, yesButtonText: yesButtonText, noButtonText: noButtonText, allowModalClose: allowModalClose);
}